package Locale::CLDR::Et::Any;

# This file auto generated
#	on Fri 20 Jun 11:27:10 pm GMT

use version;

our $VERSION = version->declare('v0.25.4');

use v5.10;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Et');

no Moose;
__PACKAGE__->meta->make_immutable;
